@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
+# Python 3.10.4 (main, Apr  2 2022, 09:04:19) [GCC 11.2.0]
 #
 # Command line options:
 #   ('--disable-generatedssuper-lookup', '')
@@ -347,6 +347,7 @@ class GeneratedsSuper(object):
     def gds_format_boolean(self, input_data, input_name=''):
         return ('%s' % input_data).lower()
     def gds_parse_boolean(self, input_data, node=None, input_name=''):
+        input_data = input_data.strip()
         if input_data in ('true', '1'):
             bval = True
         elif input_data in ('false', '0'):
@@ -526,6 +527,7 @@ class GeneratedsSuper(object):
         # The target value must match at least one of the patterns
         # in order for the test to succeed.
         found1 = True
+        target = str(target)
         for patterns1 in patterns:
             found2 = False
             for patterns2 in patterns1:
@@ -771,6 +773,7 @@ def quote_attrib(inStr):
     s1 = s1.replace('&', '&amp;')
     s1 = s1.replace('<', '&lt;')
     s1 = s1.replace('>', '&gt;')
+    s1 = s1.replace('\n', '&#10;')
     if '"' in s1:
         if "'" in s1:
             s1 = '"%s"' % s1.replace('"', "&quot;")
