@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
+# Python 3.10.4 (main, Apr  2 2022, 09:04:19) [GCC 11.2.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -354,6 +354,7 @@ except ModulenotfoundExp_ as exp:
         def gds_format_boolean(self, input_data, input_name=''):
             return ('%s' % input_data).lower()
         def gds_parse_boolean(self, input_data, node=None, input_name=''):
+            input_data = input_data.strip()
             if input_data in ('true', '1'):
                 bval = True
             elif input_data in ('false', '0'):
@@ -533,6 +534,7 @@ except ModulenotfoundExp_ as exp:
             # The target value must match at least one of the patterns
             # in order for the test to succeed.
             found1 = True
+            target = str(target)
             for patterns1 in patterns:
                 found2 = False
                 for patterns2 in patterns1:
@@ -778,6 +780,7 @@ def quote_attrib(inStr):
     s1 = s1.replace('&', '&amp;')
     s1 = s1.replace('<', '&lt;')
     s1 = s1.replace('>', '&gt;')
+    s1 = s1.replace('\n', '&#10;')
     if '"' in s1:
         if "'" in s1:
             s1 = '"%s"' % s1.replace('"', "&quot;")
@@ -1019,89 +1022,89 @@ class oneperEnumType01_1(str, Enum):
     TOKEN='token'
 
 
-class oneperType02_1(GeneratedsSuper):
+class oneperType03_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('clientname', 'xs:string', 0, 0, {'name': 'clientname', 'type': 'xs:string'}, None),
+        MemberSpec_('helpername', 'xs:string', 0, 0, {'name': 'helpername', 'type': 'xs:string'}, None),
         MemberSpec_('inner01', 'oneperType02_2', 0, 0, {'name': 'inner01', 'type': 'oneperType02_2'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, clientname=None, inner01=None, gds_collector_=None, **kwargs_):
+    def __init__(self, helpername=None, inner01=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.clientname = clientname
-        self.clientname_nsprefix_ = None
+        self.helpername = helpername
+        self.helpername_nsprefix_ = None
         self.inner01 = inner01
         self.inner01_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType02_1)
+                CurrentSubclassModule_, oneperType03_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType02_1.subclass:
-            return oneperType02_1.subclass(*args_, **kwargs_)
+        if oneperType03_1.subclass:
+            return oneperType03_1.subclass(*args_, **kwargs_)
         else:
-            return oneperType02_1(*args_, **kwargs_)
+            return oneperType03_1(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_clientname(self):
-        return self.clientname
-    def set_clientname(self, clientname):
-        self.clientname = clientname
+    def get_helpername(self):
+        return self.helpername
+    def set_helpername(self, helpername):
+        self.helpername = helpername
     def get_inner01(self):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
     def _hasContent(self):
         if (
-            self.clientname is not None or
+            self.helpername is not None or
             self.inner01 is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType02_1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_1', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType03_1')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType02_1':
+        if self.original_tagname_ is not None and name_ == 'oneperType03_1':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType02_1')
+        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType03_1')
         if self._hasContent():
             outfile.write('>%s' % (eol_, ))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType02_1', pretty_print=pretty_print)
+            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType03_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType02_1'):
+    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType03_1'):
         pass
-    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_1', fromsubclass_=False, pretty_print=True):
+    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_1', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.clientname is not None:
-            namespaceprefix_ = self.clientname_nsprefix_ + ':' if (UseCapturedNS_ and self.clientname_nsprefix_) else ''
+        if self.helpername is not None:
+            namespaceprefix_ = self.helpername_nsprefix_ + ':' if (UseCapturedNS_ and self.helpername_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%sclientname>%s</%sclientname>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.clientname), input_name='clientname')), namespaceprefix_ , eol_))
+            outfile.write('<%shelpername>%s</%shelpername>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.helpername), input_name='helpername')), namespaceprefix_ , eol_))
         if self.inner01 is not None:
             namespaceprefix_ = self.inner01_nsprefix_ + ':' if (UseCapturedNS_ and self.inner01_nsprefix_) else ''
             self.inner01.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner01', pretty_print=pretty_print)
@@ -1119,95 +1122,95 @@ class oneperType02_1(GeneratedsSuper):
     def _buildAttributes(self, node, attrs, already_processed):
         pass
     def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'clientname':
+        if nodeName_ == 'helpername':
             value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'clientname')
-            value_ = self.gds_validate_string(value_, node, 'clientname')
-            self.clientname = value_
-            self.clientname_nsprefix_ = child_.prefix
+            value_ = self.gds_parse_string(value_, node, 'helpername')
+            value_ = self.gds_validate_string(value_, node, 'helpername')
+            self.helpername = value_
+            self.helpername_nsprefix_ = child_.prefix
         elif nodeName_ == 'inner01':
             obj_ = oneperType02_2.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.inner01 = obj_
             obj_.original_tagname_ = 'inner01'
-# end class oneperType02_1
+# end class oneperType03_1
 
 
-class oneperType02_2(GeneratedsSuper):
+class oneperType03_2(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('clientdescription', 'xs:string', 0, 0, {'name': 'clientdescription', 'type': 'xs:string'}, None),
+        MemberSpec_('helperdescription', 'xs:string', 0, 0, {'name': 'helperdescription', 'type': 'xs:string'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, clientdescription=None, gds_collector_=None, **kwargs_):
+    def __init__(self, helperdescription=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.clientdescription = clientdescription
-        self.clientdescription_nsprefix_ = None
+        self.helperdescription = helperdescription
+        self.helperdescription_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType02_2)
+                CurrentSubclassModule_, oneperType03_2)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType02_2.subclass:
-            return oneperType02_2.subclass(*args_, **kwargs_)
+        if oneperType03_2.subclass:
+            return oneperType03_2.subclass(*args_, **kwargs_)
         else:
-            return oneperType02_2(*args_, **kwargs_)
+            return oneperType03_2(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_clientdescription(self):
-        return self.clientdescription
-    def set_clientdescription(self, clientdescription):
-        self.clientdescription = clientdescription
+    def get_helperdescription(self):
+        return self.helperdescription
+    def set_helperdescription(self, helperdescription):
+        self.helperdescription = helperdescription
     def _hasContent(self):
         if (
-            self.clientdescription is not None
+            self.helperdescription is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_2', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType02_2')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_2', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType03_2')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType02_2':
+        if self.original_tagname_ is not None and name_ == 'oneperType03_2':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType02_2')
+        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType03_2')
         if self._hasContent():
             outfile.write('>%s' % (eol_, ))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType02_2', pretty_print=pretty_print)
+            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType03_2', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType02_2'):
+    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType03_2'):
         pass
-    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_2', fromsubclass_=False, pretty_print=True):
+    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_2', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.clientdescription is not None:
-            namespaceprefix_ = self.clientdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.clientdescription_nsprefix_) else ''
+        if self.helperdescription is not None:
+            namespaceprefix_ = self.helperdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.helperdescription_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%sclientdescription>%s</%sclientdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.clientdescription), input_name='clientdescription')), namespaceprefix_ , eol_))
+            outfile.write('<%shelperdescription>%s</%shelperdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.helperdescription), input_name='helperdescription')), namespaceprefix_ , eol_))
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1222,17 +1225,17 @@ class oneperType02_2(GeneratedsSuper):
     def _buildAttributes(self, node, attrs, already_processed):
         pass
     def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'clientdescription':
+        if nodeName_ == 'helperdescription':
             value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'clientdescription')
-            value_ = self.gds_validate_string(value_, node, 'clientdescription')
-            self.clientdescription = value_
-            self.clientdescription_nsprefix_ = child_.prefix
-# end class oneperType02_2
+            value_ = self.gds_parse_string(value_, node, 'helperdescription')
+            value_ = self.gds_validate_string(value_, node, 'helperdescription')
+            self.helperdescription = value_
+            self.helperdescription_nsprefix_ = child_.prefix
+# end class oneperType03_2
 
 
 GDSClassesMapping = {
-    'root02': oneperType02_1,
+    'root03': oneperType03_1,
 }
 
 
@@ -1280,8 +1283,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType02_1'
-        rootClass = oneperType02_1
+        rootTag = 'oneperType03_1'
+        rootClass = oneperType03_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1312,8 +1315,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType02_1'
-        rootClass = oneperType02_1
+        rootTag = 'oneperType03_1'
+        rootClass = oneperType03_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if mapping is None:
@@ -1358,8 +1361,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType02_1'
-        rootClass = oneperType02_1
+        rootTag = 'oneperType03_1'
+        rootClass = oneperType03_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1386,8 +1389,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType02_1'
-        rootClass = oneperType02_1
+        rootTag = 'oneperType03_1'
+        rootClass = oneperType03_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1395,8 +1398,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
         doc = None
         rootNode = None
 ##     if not silence:
-##         sys.stdout.write('#from oneperType02_1One import *\n\n')
-##         sys.stdout.write('import oneperType02_1One as model_\n\n')
+##         sys.stdout.write('#from oneperType03_1One import *\n\n')
+##         sys.stdout.write('import oneperType03_1One as model_\n\n')
 ##         sys.stdout.write('rootObj = model_.rootClass(\n')
 ##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
@@ -1429,5 +1432,7 @@ __all__ = [
     "oneperType01_1",
     "oneperType01_2",
     "oneperType02_1",
-    "oneperType02_2"
+    "oneperType02_2",
+    "oneperType03_1",
+    "oneperType03_2"
 ]
