@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
+# Python 3.10.4 (main, Apr  2 2022, 09:04:19) [GCC 11.2.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -352,6 +352,7 @@ except ModulenotfoundExp_ as exp:
         def gds_format_boolean(self, input_data, input_name=''):
             return ('%s' % input_data).lower()
         def gds_parse_boolean(self, input_data, node=None, input_name=''):
+            input_data = input_data.strip()
             if input_data in ('true', '1'):
                 bval = True
             elif input_data in ('false', '0'):
@@ -531,6 +532,7 @@ except ModulenotfoundExp_ as exp:
             # The target value must match at least one of the patterns
             # in order for the test to succeed.
             found1 = True
+            target = str(target)
             for patterns1 in patterns:
                 found2 = False
                 for patterns2 in patterns1:
@@ -776,6 +778,7 @@ def quote_attrib(inStr):
     s1 = s1.replace('&', '&amp;')
     s1 = s1.replace('<', '&lt;')
     s1 = s1.replace('>', '&gt;')
+    s1 = s1.replace('\n', '&#10;')
     if '"' in s1:
         if "'" in s1:
             s1 = '"%s"' % s1.replace('"', "&quot;")
@@ -1338,10 +1341,18 @@ class DefaultType1(GeneratedsSuper):
             namespaceprefix_ = self.default03_nsprefix_ + ':' if (UseCapturedNS_ and self.default03_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault03>%s</%sdefault03>%s' % (namespaceprefix_ , self.gds_format_float(self.default03, input_name='default03'), namespaceprefix_ , eol_))
+        if self.default03 is None:
+            namespaceprefix_ = self.default03_nsprefix_ + ':' if (UseCapturedNS_ and self.default03_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault03>23.45</%sdefault03/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.default04 is not None:
             namespaceprefix_ = self.default04_nsprefix_ + ':' if (UseCapturedNS_ and self.default04_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault04>%s</%sdefault04>%s' % (namespaceprefix_ , self.gds_format_double(self.default04, input_name='default04'), namespaceprefix_ , eol_))
+        if self.default04 is None:
+            namespaceprefix_ = self.default04_nsprefix_ + ':' if (UseCapturedNS_ and self.default04_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault04>54.32</%sdefault04/>%s' % (namespaceprefix_,namespace_prefix, eol_))
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
