@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
+# Python 3.10.4 (main, Apr  2 2022, 09:04:19) [GCC 11.2.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -353,6 +353,7 @@ except ModulenotfoundExp_ as exp:
         def gds_format_boolean(self, input_data, input_name=''):
             return ('%s' % input_data).lower()
         def gds_parse_boolean(self, input_data, node=None, input_name=''):
+            input_data = input_data.strip()
             if input_data in ('true', '1'):
                 bval = True
             elif input_data in ('false', '0'):
@@ -532,6 +533,7 @@ except ModulenotfoundExp_ as exp:
             # The target value must match at least one of the patterns
             # in order for the test to succeed.
             found1 = True
+            target = str(target)
             for patterns1 in patterns:
                 found2 = False
                 for patterns2 in patterns1:
@@ -777,6 +779,7 @@ def quote_attrib(inStr):
     s1 = s1.replace('&', '&amp;')
     s1 = s1.replace('<', '&lt;')
     s1 = s1.replace('>', '&gt;')
+    s1 = s1.replace('\n', '&#10;')
     if '"' in s1:
         if "'" in s1:
             s1 = '"%s"' % s1.replace('"', "&quot;")
@@ -1747,6 +1750,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default01_nsprefix_ + ':' if (UseCapturedNS_ and self.default01_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault01>%s</%sdefault01>%s' % (namespaceprefix_ , self.gds_format_integer(self.default01, input_name='default01'), namespaceprefix_ , eol_))
+        if self.default01 is None:
+            namespaceprefix_ = self.default01_nsprefix_ + ':' if (UseCapturedNS_ and self.default01_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault01>23</%sdefault01/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal01 is not None:
             namespaceprefix_ = self.normal01_nsprefix_ + ':' if (UseCapturedNS_ and self.normal01_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1755,6 +1762,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default02_nsprefix_ + ':' if (UseCapturedNS_ and self.default02_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault02>%s</%sdefault02>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.default02), input_name='default02')), namespaceprefix_ , eol_))
+        if self.default02 is None:
+            namespaceprefix_ = self.default02_nsprefix_ + ':' if (UseCapturedNS_ and self.default02_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault02>Peach</%sdefault02/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal02 is not None:
             namespaceprefix_ = self.normal02_nsprefix_ + ':' if (UseCapturedNS_ and self.normal02_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1763,6 +1774,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default03_nsprefix_ + ':' if (UseCapturedNS_ and self.default03_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault03>%s</%sdefault03>%s' % (namespaceprefix_ , self.gds_format_float(self.default03, input_name='default03'), namespaceprefix_ , eol_))
+        if self.default03 is None:
+            namespaceprefix_ = self.default03_nsprefix_ + ':' if (UseCapturedNS_ and self.default03_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault03>23.45</%sdefault03/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal03 is not None:
             namespaceprefix_ = self.normal03_nsprefix_ + ':' if (UseCapturedNS_ and self.normal03_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1771,6 +1786,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default04_nsprefix_ + ':' if (UseCapturedNS_ and self.default04_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault04>%s</%sdefault04>%s' % (namespaceprefix_ , self.gds_format_double(self.default04, input_name='default04'), namespaceprefix_ , eol_))
+        if self.default04 is None:
+            namespaceprefix_ = self.default04_nsprefix_ + ':' if (UseCapturedNS_ and self.default04_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault04>54.32</%sdefault04/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal04 is not None:
             namespaceprefix_ = self.normal04_nsprefix_ + ':' if (UseCapturedNS_ and self.normal04_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1779,10 +1798,18 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default05a_nsprefix_ + ':' if (UseCapturedNS_ and self.default05a_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault05a>%s</%sdefault05a>%s' % (namespaceprefix_ , self.gds_format_boolean(self.default05a, input_name='default05a'), namespaceprefix_ , eol_))
+        if self.default05a is None:
+            namespaceprefix_ = self.default05a_nsprefix_ + ':' if (UseCapturedNS_ and self.default05a_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault05a>true</%sdefault05a/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.default05b is not None:
             namespaceprefix_ = self.default05b_nsprefix_ + ':' if (UseCapturedNS_ and self.default05b_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault05b>%s</%sdefault05b>%s' % (namespaceprefix_ , self.gds_format_boolean(self.default05b, input_name='default05b'), namespaceprefix_ , eol_))
+        if self.default05b is None:
+            namespaceprefix_ = self.default05b_nsprefix_ + ':' if (UseCapturedNS_ and self.default05b_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault05b>false</%sdefault05b/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal05 is not None:
             namespaceprefix_ = self.normal05_nsprefix_ + ':' if (UseCapturedNS_ and self.normal05_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1791,6 +1818,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default06_nsprefix_ + ':' if (UseCapturedNS_ and self.default06_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault06>%s</%sdefault06>%s' % (namespaceprefix_ , self.gds_format_date(self.default06, input_name='default06'), namespaceprefix_ , eol_))
+        if self.default06 is None:
+            namespaceprefix_ = self.default06_nsprefix_ + ':' if (UseCapturedNS_ and self.default06_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault06>2015-06-21</%sdefault06/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal06 is not None:
             namespaceprefix_ = self.normal06_nsprefix_ + ':' if (UseCapturedNS_ and self.normal06_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1799,6 +1830,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default07_nsprefix_ + ':' if (UseCapturedNS_ and self.default07_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault07>%s</%sdefault07>%s' % (namespaceprefix_ , self.gds_format_time(self.default07, input_name='default07'), namespaceprefix_ , eol_))
+        if self.default07 is None:
+            namespaceprefix_ = self.default07_nsprefix_ + ':' if (UseCapturedNS_ and self.default07_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault07>11:10:09</%sdefault07/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal07 is not None:
             namespaceprefix_ = self.normal07_nsprefix_ + ':' if (UseCapturedNS_ and self.normal07_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
@@ -1807,6 +1842,10 @@ class DefaultType2(GeneratedsSuper):
             namespaceprefix_ = self.default08_nsprefix_ + ':' if (UseCapturedNS_ and self.default08_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
             outfile.write('<%sdefault08>%s</%sdefault08>%s' % (namespaceprefix_ , self.gds_format_datetime(self.default08, input_name='default08'), namespaceprefix_ , eol_))
+        if self.default08 is None:
+            namespaceprefix_ = self.default08_nsprefix_ + ':' if (UseCapturedNS_ and self.default08_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sdefault08>2015-06-21T14:13:12</%sdefault08/>%s' % (namespaceprefix_,namespace_prefix, eol_))
         if self.normal08 is not None:
             namespaceprefix_ = self.normal08_nsprefix_ + ':' if (UseCapturedNS_ and self.normal08_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
